@@ -182,7 +182,7 @@ private:
 private:
     void RunImpl();
 
-#if IUTEST_HAS_EXCEPTIONS && IUTEST_HAS_SEH
+#if IUTEST_HAS_SEH && IUTEST_HAS_EXCEPTIONS
 #if IUTEST_HAS_MINIDUMP
     void MiniDump(_EXCEPTION_POINTERS* ep);
 #endif
